@@ -1,3 +1,3 @@
 from .app import *
 from .views import *
-from __main__ import *
\ No newline at end of file
+from .templates import *
\ No newline at end of file
