@@ -1,8 +1,11 @@
 import os
 import sys
-from .templates import main, index, css
 import spinne
 
+import main
+import index
+import css # TODO: add css support
+
 def main(name):
     print("Creating app...")
     if not os.path.exists(name):
